@@ -9,13 +9,6 @@
 
 #include "pomp_internal.h"
 
-SEXP add_skel_args(SEXP args, SEXP Snames, SEXP Pnames, SEXP Cnames);
-void eval_skeleton_R(double *f, double *time, double *x, double *p, SEXP fn, SEXP args, SEXP Snames, int nvars, int npars, int ncovars, int ntimes, int nrepx, int nrepp, int nreps, lookup_table_t *covar_table, double *cov);
-void iterate_skeleton_R(double *X, double t, double deltat, double *time, double *x, double *p, SEXP fn, SEXP args, SEXP Snames, int nvars, int npars, int ncovars, int ntimes, int nrepp, int nreps, int nzeros, lookup_table_t *covar_table, int *zeroindex, double *cov);
-void eval_skeleton_native(double *f, double *time, double *x, double *p, int nvars, int npars, int ncovars, int ntimes, int nrepx, int nrepp, int nreps, int *sidx, int *pidx, int *cidx, lookup_table_t *covar_table, pomp_skeleton *fun, SEXP args, double *cov);
-void iterate_skeleton_native(double *X, double t, double deltat, double *time, double *x, double *p, int nvars, int npars, int ncovars, int ntimes, int nrepp, int nreps, int nzeros, int *sidx, int *pidx, int *cidx, lookup_table_t *covar_table, int *zeroindex, pomp_skeleton *fun, SEXP args, double *cov);
-SEXP do_skeleton(SEXP object, SEXP x, SEXP t, SEXP params, SEXP gnsi);
-
 SEXP add_skel_args (SEXP args, SEXP Snames, SEXP Pnames, SEXP Cnames)
 {
 
@@ -99,13 +92,14 @@ static R_INLINE SEXP ret_array (int nvars, int nreps, int ntimes, SEXP Snames)
   return X;
 }
 
-void eval_skeleton_R (
-    double *f, double *time, double *x, double *p,
-    SEXP fn, SEXP args, SEXP Snames,
-    int nvars, int npars, int ncovars, int ntimes,
-    int nrepx, int nrepp, int nreps,
-    lookup_table_t *covar_table, double *cov)
-{
+void eval_skeleton_R
+(
+ double *f, double *time, double *x, double *p,
+ SEXP fn, SEXP args, SEXP Snames,
+ int nvars, int npars, int ncovars, int ntimes,
+ int nrepx, int nrepp, int nreps,
+ lookup_table_t *covar_table, double *cov
+ ) {
 
   SEXP ans, nm;
   double *fs;
